@@ -14,10 +14,9 @@ enum InterfaceKeyType
 	INTERFACEKEY_NONE=0,
 	INTERFACEKEY_SELECT,
 	//********************* MAIN KEY LOSS
-	/*
+	//******************** ADVMODE
 	INTERFACEKEY_SEC_SELECT,
 	INTERFACEKEY_DESELECT,
-	*/
 	INTERFACEKEY_SELECT_ALL,
 	/*
 	INTERFACEKEY_DESELECT_ALL,
@@ -57,12 +56,11 @@ enum InterfaceKeyType
 	INTERFACEKEY_CONTEXT_SCROLL_DOWN,
 	INTERFACEKEY_CONTEXT_SCROLL_PAGEUP,
 	INTERFACEKEY_CONTEXT_SCROLL_PAGEDOWN,
-	/*
+	//******************* ADVMODE
 	INTERFACEKEY_SECONDSCROLL_UP,
 	INTERFACEKEY_SECONDSCROLL_DOWN,
 	INTERFACEKEY_SECONDSCROLL_PAGEUP,
 	INTERFACEKEY_SECONDSCROLL_PAGEDOWN,
-	*/
 	INTERFACEKEY_CURSOR_UP,
 	INTERFACEKEY_CURSOR_DOWN,
 	INTERFACEKEY_CURSOR_LEFT,
@@ -105,7 +103,12 @@ enum InterfaceKeyType
 	INTERFACEKEY_KEYBOARD_CURSOR_DOWN_Z,
 	INTERFACEKEY_KEYBOARD_CURSOR_UP_Z_AUX,
 	INTERFACEKEY_KEYBOARD_CURSOR_DOWN_Z_AUX,
-	//INTERFACEKEY_MENU_CONFIRM,
+	INTERFACEKEY_ADV_VIEW_UP_Z,
+	INTERFACEKEY_ADV_VIEW_DOWN_Z,
+	INTERFACEKEY_ADV_VIEW_UP_Z_FAST,
+	INTERFACEKEY_ADV_VIEW_DOWN_Z_FAST,
+	//******************** ADVMODE
+	INTERFACEKEY_MENU_CONFIRM,
 	//INTERFACEKEY_SAVE_BINDINGS,
 	//INTERFACEKEY_LOAD_BINDINGS,
 	INTERFACEKEY_MACRO_BREAK,
@@ -114,7 +117,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_SAVE_MACRO,
 	INTERFACEKEY_LOAD_MACRO,
 	INTERFACEKEY_PREFIX,
-	/*
+	//************************ ADVMODE
 	INTERFACEKEY_OPTION1,
 	INTERFACEKEY_OPTION2,
 	INTERFACEKEY_OPTION3,
@@ -155,7 +158,6 @@ enum InterfaceKeyType
 	INTERFACEKEY_SEC_OPTION18,
 	INTERFACEKEY_SEC_OPTION19,
 	INTERFACEKEY_SEC_OPTION20,
-	*/
 	INTERFACEKEY_CUSTOM_A,
 	INTERFACEKEY_CUSTOM_B,
 	INTERFACEKEY_CUSTOM_C,
@@ -365,7 +367,6 @@ enum InterfaceKeyType
 	*/
 
 	ADVENTURERKEY_START,
-	/*
 	INTERFACEKEY_A_RETURN_TO_ARENA=ADVENTURERKEY_START,
 	INTERFACEKEY_A_MOVE_N,
 	INTERFACEKEY_A_MOVE_S,
@@ -423,6 +424,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_WAIT,
 	INTERFACEKEY_A_SHORT_WAIT,
 	INTERFACEKEY_A_ATTACK,
+	INTERFACEKEY_A_WRESTLE,
 	INTERFACEKEY_A_ATTACK_CONFIRM,
 	INTERFACEKEY_QUICK_ATTACK,
 	INTERFACEKEY_HEAVY_ATTACK,
@@ -432,6 +434,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_MULTI_ATTACK,
 	INTERFACEKEY_A_LOOK,
 	INTERFACEKEY_A_SEARCH,
+	INTERFACEKEY_A_NOCK,
 	INTERFACEKEY_A_ODOR,
 	INTERFACEKEY_A_DISPLAY_ODOR,
 	INTERFACEKEY_A_YIELD,
@@ -441,8 +444,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_JUMP,
 	INTERFACEKEY_A_HOLD,
 	INTERFACEKEY_A_TALK,
-	INTERFACEKEY_A_CONV_PERSUADE,
-	INTERFACEKEY_A_CONV_INTIMIDATE,
+	INTERFACEKEY_A_PERFORM,
 	INTERFACEKEY_A_ASSUME_IDENTITY_NEW,
 	INTERFACEKEY_A_ASSUME_IDENTITY_NONE,
 	INTERFACEKEY_A_ASSUME_IDENTITY_NAME,
@@ -457,6 +459,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_ACTION_POWER,
 	INTERFACEKEY_A_ACTION_COMPOSE,
 	INTERFACEKEY_A_ACTION_WRITE,
+	INTERFACEKEY_A_ABILITY,
 	INTERFACEKEY_A_CONSTRUCTION,
 	INTERFACEKEY_ADV_CONSTRUCTION_ZONE_NEW,
 	INTERFACEKEY_ADV_CONSTRUCTION_ZONE_EDIT,
@@ -556,7 +559,12 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_BARTER_CURRENCY_2,
 	INTERFACEKEY_A_BARTER_TRADE,
 	INTERFACEKEY_A_BARTER_SHOW,
-	*/
+	INTERFACEKEY_ADVENTURE_LIST_SCROLL_PAGEUP,
+	INTERFACEKEY_ADVENTURE_LIST_SCROLL_PAGEDOWN,
+	INTERFACEKEY_ADVENTURE_LIST_SCROLL_UP,
+	INTERFACEKEY_ADVENTURE_LIST_SCROLL_DOWN,
+
+	//***************************** NEW KEYS
 
 	EMBARKKEY_START,
 	/*
